% True parameters
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Takes a thermodynamically infeasible value of kappa and computes 
% the closest (in a least-squares sense) feasible kappa using the 
% Moore-Penrose pseudoinverse
%

function [logKappaTrue] = findTrue(logKappaInfeas,W,permMatM)

%
% Set parameters
%

M  = size(permMatM,1);
M2 = size(W,1);
M1 = M-M2;

%
% Find free variables
%

logKappaForward   = logKappaInfeas(1:2:(2*M-1));
logKappaBackward  = logKappaInfeas(2:2:(2*M));
newLogKapForward  = logKappaForward'*permMatM;
newLogKapForward  = newLogKapForward';
newLogKapBackward = logKappaBackward'*permMatM;
newLogKapBackward = newLogKapBackward';

%
% Find least squares solution
%

newLogKappaTrue = [eye(M+M1);W]*pinv([eye(M+M1);W])*[newLogKapForward;newLogKapBackward];

%
% convert back to original ordering
%

logKappaTrueForw = newLogKappaTrue(1:M)'*permMatM';
logKappaTrueForw = logKappaTrueForw';
logKappaTrueBack = newLogKappaTrue((M+1):end)'*permMatM';
logKappaTrueBack = logKappaTrueBack';

logKappaTrue = zeros(2*M,1);
logKappaTrue(1:2:(2*M-1)) = logKappaTrueForw;
logKappaTrue(2:2:(2*M))   = logKappaTrueBack;