% Plot molecular dynamics and noisy measurements
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function plotit(x0,tstep,N,kappa,tol_high,timings,tq,FolderName)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Initialization
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

close all

tmp = dlmread('../data/data_0.txt');
Q = size(tmp,1)-1;
ytmp(1:Q,1:N) = tmp(1:Q,1:N);
ytmp = exp(ytmp);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Calculate molecular dynamics
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

[t,xtmp] = oden13(kappa,x0,[tol_high;tol_high],timings);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Make plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

set(0,'DefaultAxesLineWidth',2,'DefaultAxesFontSize',14,...
      'DefaultAxesFontWeight','normal');
lnw = 2;

figure
plot(tq*tstep,ytmp(:,1),'k*');
line(t,xtmp(:,1),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_1:  Shc*}');
saveas(gcf,['../results/' FolderName '/figures/data/y_1.fig'])
   
figure
plot(tq*tstep,ytmp(:,2),'k*');
line(t,xtmp(:,2),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_2:  Grb2}');
saveas(gcf,['../results/' FolderName '/figures/data/y_2.fig'])

figure
plot(tq*tstep,ytmp(:,3),'k*');
line(t,xtmp(:,3),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_3:  Shc*-Grb2}');
saveas(gcf,['../results/' FolderName '/figures/data/y_3.fig'])
   
figure
plot(tq*tstep,ytmp(:,4),'k*');
line(t,xtmp(:,4),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_4:  Sos}');
saveas(gcf,['../results/' FolderName '/figures/data/y_4.fig'])

figure
plot(tq*tstep,ytmp(:,5),'k*');
line(t,xtmp(:,5),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_5:  Shc*-Grb2-Sos}');
saveas(gcf,['../results/' FolderName '/figures/data/y_5.fig'])
   
figure
plot(tq*tstep,ytmp(:,6),'k*');
line(t,xtmp(:,6),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_6:  Grb2-Sos}');
saveas(gcf,['../results/' FolderName '/figures/data/y_6.fig'])

figure
plot(tq*tstep,ytmp(:,7),'k*');
line(t,xtmp(:,7),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_7:  (EGF-EGFR*)2-GAP}');
saveas(gcf,['../results/' FolderName '/figures/data/y_7.fig'])

figure
plot(tq*tstep,ytmp(:,8),'k*');
line(t,xtmp(:,8),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_8: (EGF-EGFR*)2-GAP-Grb2}');
saveas(gcf,['../results/' FolderName '/figures/data/y_8.fig'])

figure
plot(tq*tstep,ytmp(:,9),'k*');
line(t,xtmp(:,9),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_9:  (EGF-EGFR*)2-GAP-Grb2-Sos}');
saveas(gcf,['../results/' FolderName '/figures/data/y_9.fig'])

figure
plot(tq*tstep,ytmp(:,10),'k*');
line(t,xtmp(:,10),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{10}:  Ras-GDP}');
saveas(gcf,['../results/' FolderName '/figures/data/y_10.fig'])

figure
plot(tq*tstep,ytmp(:,11),'k*');
line(t,xtmp(:,11),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{11}:  (EGF-EGFR*)2-GAP-Grb2-Ras-GDP}');
saveas(gcf,['../results/' FolderName '/figures/data/y_11.fig'])

figure
plot(tq*tstep,ytmp(:,12),'k*');
line(t,xtmp(:,12),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{12}:  Ras-GTP*}');
saveas(gcf,['../results/' FolderName '/figures/data/y_12.fig'])

figure
plot(tq*tstep,ytmp(:,13),'k*');
line(t,xtmp(:,13),'Color',[1 0 0],'Linewidth',lnw)
h = legend(' data',' true');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{13}:  (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GTP}');
saveas(gcf,['../results/' FolderName '/figures/data/y_13.fig'])