% Plot true vs. initial molecular dynamics
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function tiplotit(x0,z,zest,kappa,kappaest,tol_high,timings,FolderName)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Initialization
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

close all

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Calculate true and prior mode estimated molecular dynamics
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

[t,init] = oden13(kappa,x0,[tol_high;tol_high],timings);
[t,xest] = oden13(kappaest,x0,[tol_high;tol_high],timings);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Make plots
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

set(0,'DefaultAxesLineWidth',2,'DefaultAxesFontSize',14,...
      'DefaultAxesFontWeight','normal');
lnw = 2;

figure
plot([1,2,3,4,5,6,7,8,9],z,'rx','MarkerSize',11,'LineWidth',2)
hold on
plot([1,2,3,4,5,6,7,8,9],zest,'o','MarkerSize',11,'LineWidth',2)
axis tight
xlabel('\bf reaction','fontsize',12);
ylabel('\bf log-ratio value','fontsize',12);
title('true (red) vs. estimated (blue) log-ratios')
saveas(gcf,['../results/' FolderName '/figures/initial/init_0.fig'])

figure
plot(t,init(:,1),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,1),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_1:  Shc*}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_1.fig'])
   
figure
plot(t,init(:,2),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,2),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_2:  Grb2}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_2.fig'])

figure
plot(t,init(:,3),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,3),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_3:  Shc*-Grb2}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_3.fig'])
   
figure
plot(t,init(:,4),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,4),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_4:  Sos}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_4.fig'])

figure
plot(t,init(:,5),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,5),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_5:  Shc*-Grb2-Sos}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_5.fig'])
   
figure
plot(t,init(:,6),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,6),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_6:  Grb2-Sos}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_6.fig'])

figure
plot(t,init(:,7),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,7),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_7:  (EGF-EGFR*)2-GAP}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_7.fig'])

figure
plot(t,init(:,8),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,8),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_8:  (EGF-EGFR*)2-GAP-Grb2}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_8.fig'])

figure
plot(t,init(:,9),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,9),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_9:  (EGF-EGFR*)2-GAP-Grb2-Sos}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_9.fig'])

figure
plot(t,init(:,10),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,10),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{10}:  Ras-GDP}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_10.fig'])

figure
plot(t,init(:,11),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,11),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{11}:  (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GDP}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_11.fig'])

figure
plot(t,init(:,12),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,12),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{12}:  Ras-GTP*}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_12.fig'])

figure
plot(t,init(:,13),'Color',[1 0 0],'Linewidth',lnw)
hold on
plot(t,xest(:,13),'Color',[0 0 1],'Linewidth',lnw)
h = legend(' true',' initial');
set(h,'Location','NorthEast');
   xlabel('time (minutes)');
   ylabel('molecules/cell');
   title('{\bf X_{13}:  (EGF-EGFR*)2-GAP-Grb2-Sos-Ras-GTP}');
saveas(gcf,['../results/' FolderName '/figures/initial/init_13.fig'])