% Reaction rate log-ratio estimation
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%            Posterior Mode Rate Estimation           %%%%%%%%%%%
%%%%%%%%%%%         Authors: Jenkinson, Zhong, Goutsias         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function zest = zetaest(SS,permMatM,stoich,y,yp,Q,N,P,M,svdtol)

%
% Compute ytilde
%

yst = repmat(0,[P+1,N]);

yst(1,:) = y(Q+1,:);             % steady-state data from reference system  
for p = 1:P
    yst(p+1,:) = yp(P*Q+p,:);    % steady-state data from perturbed systems  
end
ytilde = sum(yst)*stoich./(P+1);
ytilde = ytilde';

%
% Compute SVD of Xi
%

Xi      = stoich'*stoich;
[U,S,U] = svd(Xi); 
S0      = diag(S(S > svdtol*max(max(S))));
M0      = M - size(S0,1);
U0      = U(1:M,1:M-M0);

%
% Find Wegscheider conditions for z
%

GUnordered = [eye(size(SS,2));SS]; 

G = GUnordered'*permMatM'; 
G = G';

%
% Compute zest using the Moore-Penrose psuedoinverse
%

zest = G*pinv(U0'*G)*U0'*ytilde;