% Plot of forward log-rate prior density
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%           Forward log-rate prior density            %%%%%%%%%%%
%%%%%%%%%%%         Authors: Goutsias, Zhong, Jenkinson         %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

clear all;
close all;

logkappa = (-40:0.01:20); 

logkappa_0 = -5.1010;  % maximum possible logkappa value when lambda = 0
tau        =  1.8990;  % the location of the distribution of logkappa 
                       % is at logkappa_0-tau
lambda     =  0.7409;  % the scale of the distribution of logkappa 
%lambda    =  5.3849;  % is at sqrt(tau^2+lambda^2)

for i = 1:size(logkappa,2)
    p(i) = denskappa(logkappa(i),logkappa_0,lambda,tau);
end

set(0,'DefaultAxesLineWidth',2,'DefaultAxesFontSize',14,...
      'DefaultAxesFontWeight','normal');
lnw = 2;

figure
plot(logkappa,p,'Color',[1 0 0],'Linewidth',lnw)
   axis([1.1*min(logkappa) max(logkappa) 0 1.2*max(p)])
   xlabel('\kappa_{2m-1}');
   title('{\bf forward log-rate prior density}');