% System simulation
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%   Thermodynamically Consistent Bayesian Analysis    %%%%%%%%%%%
%%%%%%%%%%%       of Closed Biochemical Reaction Systems        %%%%%%%%%%%
%%%%%%%%%%%                  System Simulation                  %%%%%%%%%%%
%%%%%%%%%%%        Authors: Jenkinson, Zhong, Goutsias          %%%%%%%%%%%
%%%%%%%%%%%              Last Modified: 11/04/2010              %%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

clear all;            % clear all parameters
close all;            % close all files

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Input parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

parameters;           % system parameters
x0_vec;               % initial molecular numbers

time     = 1;         % simulation time (in min)
tstep    = 0.005;     % time step for ODE integration
tol_high = 1e-6;      % high tolerance for ODE solver
                    
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Initialize
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

ndata     = time/tstep;      % number of output data points from ODE solver
timings   = [0,time,ndata];  % time data vector passed to custom ODE solver
reac(1:M) = 1:M;

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Solve system of ODEs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

[t,x] = oden13(kappa,x0,[tol_high,tol_high],timings);

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Plot molecular dynamics
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

plotit;